/*
 *  Copyright 2013, Enguerrand de Rochefort
 * 
 * This file is part of xdat.
 *
 * xdat is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * xdat is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with xdat.  If not, see <http://www.gnu.org/licenses/>.
 * 
 */

package actionListeners.parallelCoordinatesDisplaySettings;

import gui.dialogs.ParallelCoordinatesDisplaySettingsDialog;
import gui.panels.ParallelCoordinatesChartDisplaySettingsPanel;

import java.awt.event.*;


import xdat.*;

/**
 * ActionListener for the Ok button of a {@link ParallelCoordinatesChartDisplaySettingsPanel} that was instantiated 
 * using the constructor form {@link ParallelCoordinatesChartDisplaySettingsPanel}.
 * <p>
 * When a ChartDisplaySettingsPanel is instantiated without a ChartFrame object as the last argument, the settings 
 * made in the panel are applied to the default settings in the {@link UserPreferences}.
 * In order to do this correctly when the Ok button is pressed, the button must use this dedicated ActionListener.
 * 
 * @see ChartSpecificDisplaySettingsDialogActionListener
 */
public class DefaultDisplaySettingsDialogActionListener 
implements ActionListener
{
	
	/** Flag to enable debug message printing for this class. */
	static final boolean printLog=false;
	
	/** The dialog. */
	private ParallelCoordinatesDisplaySettingsDialog dialog;

	/**
	 * Instantiates a new default display settings dialog action listener.
	 *
	 * @param dialog the DisplaySettingsDialog
	 */
	public DefaultDisplaySettingsDialogActionListener(ParallelCoordinatesDisplaySettingsDialog dialog)
	{
		this.dialog = dialog;
		log(" Constructor: Tic label color = "+Main.getUserPreferences().getParallelCoordinatesAxisTicLabelFontColor().toString());
		
	}
	
	/* (non-Javadoc)
	 * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
	 */
	public void actionPerformed(ActionEvent e)
	{
		String actionCommand = e.getActionCommand();
		if(actionCommand == "Ok")
		{
			Main.getUserPreferences().setParallelCoordinatesVerticallyOffsetAxisLabels(this.dialog.getChartDisplaySettingsPanel().getAxisLabelVerticalOffsetCheckbox().isSelected());
			Main.getUserPreferences().setParallelCoordinatesDefaultBackgroundColor(this.dialog.getChartDisplaySettingsPanel().getChartDisplaySettingsActionListener().getBackGroundColor());
			Main.getUserPreferences().setParallelCoordinatesActiveDesignDefaultColor(this.dialog.getChartDisplaySettingsPanel().getChartDisplaySettingsActionListener().getActiveDesignColor());
			Main.getUserPreferences().setParallelCoordinatesInactiveDesignDefaultColor(this.dialog.getChartDisplaySettingsPanel().getChartDisplaySettingsActionListener().getFilteredDesignColor());
			Main.getUserPreferences().setParallelCoordinatesFilterColor(this.dialog.getChartDisplaySettingsPanel().getChartDisplaySettingsActionListener().getFilterColor());
			Main.getUserPreferences().setParallelCoordinatesShowDesignIDs(this.dialog.getChartDisplaySettingsPanel().getChartDisplaySettingsActionListener().isShowDesignIDs());
			Main.getUserPreferences().setParallelCoordinatesShowFilteredDesigns(this.dialog.getChartDisplaySettingsPanel().getChartDisplaySettingsActionListener().isShowFilteredDesigns());
			Main.getUserPreferences().setParallelCoordinatesDesignLabelFontSize((Integer)this.dialog.getChartDisplaySettingsPanel().getDesignLabelFontSizeSpinner().getValue());
			Main.getUserPreferences().setParallelCoordinatesLineThickness((Integer)this.dialog.getChartDisplaySettingsPanel().getDesignLineThicknessSpinner().getValue());
			Main.getUserPreferences().setParallelCoordinatesFilterWidth((Integer)this.dialog.getChartDisplaySettingsPanel().getFilterWidthSpinner().getValue());
			Main.getUserPreferences().setParallelCoordinatesFilterHeight((Integer)this.dialog.getChartDisplaySettingsPanel().getFilterHeightSpinner().getValue());
			
			Main.getUserPreferences().setParallelCoordinatesAxisColor(this.dialog.getAxisDisplaySettingsPanel().getAxisDisplaySettingsActionListener().getAxisColor());
			Main.getUserPreferences().setParallelCoordinatesAxisLabelFontColor(this.dialog.getAxisDisplaySettingsPanel().getAxisDisplaySettingsActionListener().getAxisLabelColor());
			Main.getUserPreferences().setParallelCoordinatesAxisTicLabelFontColor(this.dialog.getAxisDisplaySettingsPanel().getAxisDisplaySettingsActionListener().getTicLabelColor());		
			Main.getUserPreferences().setFilterInverted(this.dialog.getAxisDisplaySettingsPanel().getAxisDisplaySettingsActionListener().isInvertFilter() );
			Main.getUserPreferences().setParallelCoordinatesAxisInverted(this.dialog.getAxisDisplaySettingsPanel().getAxisDisplaySettingsActionListener().isInvertAxis() );
			Main.getUserPreferences().setParallelCoordinatesAutoFitAxis(this.dialog.getAxisDisplaySettingsPanel().getAxisDisplaySettingsActionListener().isAutoFitAxis() );
			Main.getUserPreferences().setParallelCoordinatesAxisDefaultMin(this.dialog.getAxisDisplaySettingsPanel().getAxisMin());
			Main.getUserPreferences().setParallelCoordinatesAxisDefaultMax(this.dialog.getAxisDisplaySettingsPanel().getAxisMax());
			
			Main.getUserPreferences().setParallelCoordinatesAxisWidth((Integer)this.dialog.getAxisDisplaySettingsPanel().getAxisWidthSpinner().getValue());
			Main.getUserPreferences().setParallelCoordinatesAxisLabelFontSize((Integer)this.dialog.getAxisDisplaySettingsPanel().getAxisLabelFontSizeSpinner().getValue());
			Main.getUserPreferences().setParallelCoordinatesAxisTicLength((Integer)this.dialog.getAxisDisplaySettingsPanel().getTicSizeSpinner().getValue());
			Main.getUserPreferences().setParallelCoordinatesAxisTicCount((Integer)this.dialog.getAxisDisplaySettingsPanel().getTicCountSpinner().getValue());
			Main.getUserPreferences().setParallelCoordinatesAxisTicLabelFontSize((Integer)this.dialog.getAxisDisplaySettingsPanel().getTicLabelFontSizeSpinner().getValue());
			log(" OK: Tic label color = "+Main.getUserPreferences().getParallelCoordinatesAxisTicLabelFontColor().toString());
			this.dialog.dispose();
		}
		else if(actionCommand == "Cancel")
		{
			this.dialog.dispose();
		}
		else if(actionCommand == "Yes" || actionCommand == "No" )
		{
			// Do nothing
		}
		else
		{
			System.out.println("ChartDisplaySettingsActionListener: "+e.getActionCommand());
		}
	}

	/**
	 * Prints debug information to stdout when printLog is set to true.
	 *
	 * @param message the message
	 */
	private void log(String message)
	{
		if(DefaultDisplaySettingsDialogActionListener.printLog && Main.isLoggingEnabled())
		{
			System.out.println(this.getClass().getName()+"."+message);
		}
	}	
}
